<?php

namespace Drupal\improve_line_breaks_filter\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 *
 * @package Drupal\improve_line_breaks_filter\Form
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'improve_line_breaks_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'improve_line_breaks.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('improve_line_breaks_filter.settings');
    $form['remove_empty_paragraphs'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove empty paragraphs'),
      '#description' => $this->t('Determines whether empty paragraphs (e.g. <code>&lt;p>&lt;/p&gt;</code> or <code>&lt;p>&amp;nbsp;&lt;/p&gt;</code>) will be deleted or replaced with <code>&lt;br /&gt;</code>.'),
      '#default_value' => $config->get('remove_empty_paragraphs'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('improve_line_breaks_filter.settings')
      ->set('remove_empty_paragraphs', $form_state->getValue('remove_empty_paragraphs'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
