<?php

namespace Drupal\improve_line_breaks_filter\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use Drupal\improve_line_breaks_filter\TextReplacement;

/**
 * A text filter to improve the line breaks.
 *
 * @Filter(
 *   id = "improve_line_breaks_filter",
 *   title = @Translation("Improve line breaks"),
 *   description = @Translation("Replace empty paragraphs (e.g. <code>&lt;p>&lt;/p&gt;</code> or <code>&lt;p>&amp;nbsp;&lt;/p&gt;</code>) with <code>&lt;br /&gt;</code>."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_MARKUP_LANGUAGE,
 *   weight = 50
 * )
 */
class ImproveLineBreaksFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    if (empty($text)) {
      return $text;
    }

    $result = new FilterProcessResult($text);
    $config = \Drupal::config('improve_line_breaks_filter.settings');
    $remove_empty_paragraphs = $config->get('remove_empty_paragraphs');

    $replacement = new TextReplacement();
    $result->setProcessedText($replacement->processImproveLineBreaks($text, $remove_empty_paragraphs));

    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    return $this->t("Replace empty paragraphs (e.g. <code>&lt;p>&lt;/p&gt;</code> or <code>&lt;p>&amp;nbsp;&lt;/p&gt;</code>) with <code>&lt;br /&gt;</code>.");
  }

}
